@@ -35,6 +35,31 @@ class PartialFillExchange_(Proc):
         self.buy_orders = Dict.empty(int64, order_ladder_ty)
         self.queue_model = queue_model
 
+    def reset(
+            self,
+            start_position,
+            start_balance,
+            start_fee,
+            maker_fee,
+            taker_fee,
+            tick_size,
+            lot_size,
+            snapshot
+    ):
+        self._proc_reset(
+            start_position,
+            start_balance,
+            start_fee,
+            maker_fee,
+            taker_fee,
+            tick_size,
+            lot_size,
+            snapshot
+        )
+        self.sell_orders.clear()
+        self.buy_orders.clear()
+        self.queue_model.reset()
+
     def _next_data_timestamp(self):
         return self._next_data_timestamp_column(COL_EXCH_TIMESTAMP)
 
@@ -253,6 +278,9 @@ class PartialFillExchange_(Proc):
                         )
 
     def __ack_new(self, order, timestamp):
+        if order.order_id in self.orders:
+            raise KeyError('order_id already exists')
+
         if order.side == BUY:
             # Check if the buy order price is greater than or equal to the current best ask.
             if order.price_tick >= self.depth.best_ask_tick:
@@ -430,7 +458,8 @@ class PartialFillExchange_(Proc):
             order.status = EXPIRED
             order.exch_timestamp = timestamp
             local_recv_timestamp = timestamp + self.order_latency.response(timestamp, order, self)
-            self.orders_to.append(order.copy(), local_recv_timestamp)
+            # It can overwrite another existing order on the local side if order_id is the same. So, commented out.
+            # self.orders_to.append(order.copy(), local_recv_timestamp)
             return local_recv_timestamp
 
         # Delete the order.
@@ -456,6 +485,11 @@ class PartialFillExchange_(Proc):
             exec_price_tick=0,
             delete_order=True
     ):
+        if order.status == EXPIRED \
+                or order.status == CANCELED \
+                or order.status == FILLED:
+            raise ValueError('status')
+
         order.maker = maker
         order.exec_price_tick = order.price_tick if maker else exec_price_tick
         order.exec_qty = exec_qty
